.. currentmodule:: filefisher

API reference
#############

This page provides an auto-generated summary of filefishers' API.


FileFinder
==========

.. autosummary::
   :toctree: generated/

   ~FileFinder
   ~FileFinder.create_path_name
   ~FileFinder.create_file_name
   ~FileFinder.create_full_name
   ~FileFinder.find_paths
   ~FileFinder.find_files
   ~FileFinder.find_single_path
   ~FileFinder.find_single_file


FileContainer
=============

.. autosummary::
   :toctree: generated/

   ~FileContainer
   ~FileContainer.meta
   ~FileContainer.paths
   ~FileContainer.items
   ~FileContainer.search
   ~FileContainer.concat


Filters
=======

.. autosummary::
   :toctree: generated/

   ~filters.priority_filter
